@@ -1,31 +1,34 @@
 /****************************************************************************
 **
-** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
-** Contact: http://www.qt-project.org/legal
+** Copyright (C) 2015 The Qt Company Ltd.
+** Contact: http://www.qt.io/licensing/
 **
 ** This file is part of the Qt Quick Controls module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL3$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and Digia. For licensing terms and
-** conditions see http://qt.digia.com/licensing. For further information
-** use the contact form at http://qt.digia.com/contact-us.
+** a written agreement between you and The Qt Company. For licensing terms
+** and conditions see http://www.qt.io/terms-conditions. For further
+** information use the contact form at http://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPLv3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl.html.
 **
-** In addition, as a special exception, Digia gives you certain additional
-** rights. These rights are described in the Digia Qt LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or later as published by the Free
+** Software Foundation and appearing in the file LICENSE.GPL included in
+** the packaging of this file. Please review the following information to
+** ensure the GNU General Public License version 2.0 requirements will be
+** met: http://www.gnu.org/licenses/gpl-2.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -66,6 +69,9 @@ void QQuickRangeModelPrivate::init()
     posatmin = 0;
     posatmax = 0;
     inverted = false;
+    isComplete = false;
+    positionChanged = false;
+    valueChanged = false;
 }
 
 /*!
@@ -152,10 +158,16 @@ void QQuickRangeModelPrivate::emitValueAndPositionIfChanged(const qreal oldValue
     // unchanged. This will be the case when operating with values outside range:
     const qreal newValue = q->value();
     const qreal newPosition = q->position();
-    if (!qFuzzyCompare(newValue, oldValue))
-        emit q->valueChanged(newValue);
-    if (!qFuzzyCompare(newPosition, oldPosition))
-        emit q->positionChanged(newPosition);
+
+    if (isComplete) {
+        if (!qFuzzyCompare(newValue, oldValue))
+            emit q->valueChanged(newValue);
+        if (!qFuzzyCompare(newPosition, oldPosition))
+            emit q->positionChanged(newPosition);
+    } else {
+        positionChanged |= qFuzzyCompare(oldPosition, newPosition);
+        valueChanged |= !qFuzzyCompare(oldValue, newValue);
+    }
 }
 
 /*!
@@ -343,6 +355,22 @@ qreal QQuickRangeModel::positionForValue(qreal value) const
     return d->publicPosition(unconstrainedPosition);
 }
 
+void QQuickRangeModel::classBegin()
+{
+}
+
+void QQuickRangeModel::componentComplete()
+{
+    Q_D(QQuickRangeModel);
+    d->isComplete = true;
+    emit minimumChanged(minimum());
+    emit maximumChanged(maximum());
+    if (d->valueChanged)
+        emit valueChanged(value());
+    if (d->positionChanged)
+        emit positionChanged(position());
+}
+
 /*!
     \property QQuickRangeModel::position
     \brief the current position of the model
